---
title: "Installation + Setup"
sidebarTitle: "Installation + Setup"
icon: "gear"
---

### Installing ART

The ART client can be installed into projects designed to run on any machine that runs python.

```bash
pip install openpipe-art
```

### Running the client and server locally

The ART server can be run locally on any machine with a GPU. To install the backend dependencies required for training and inference, you can install the `backend` extra:

```bash
pip install openpipe-art[backend]
```



```python
from art import TrainableModel, gather_trajectory_groups
from art.local.backend import LocalBackend

backend = LocalBackend()

model = TrainableModel(
    name="agent-001",
    project="my-agentic-task",
    base_model="Qwen/Qwen2.5-14B-Instruct",
)

await model.register(backend)

... the rest of your code ...
```

### Running the client locally and connecting to a remote server

The ART client can also be run locally and connected to a remote server, which ART will automatically provision for you. To use SkyPilot, you'll need to install the optional dependency:

```bash
pip install openpipe-art[skypilot]
```

Then you can use SkyPilotBackend in your code:

```python
from art import TrainableModel, gather_trajectory_groups
from art.skypilot.backend import SkyPilotBackend

backend = await SkyPilotBackend.initialize_cluster(
    cluster_name="my-cluster",
    gpu="H100"
)

model = TrainableModel(
    name="agent-001",
    project="my-agentic-task",
    base_model="Qwen/Qwen2.5-14B-Instruct",
)

await model.register(backend)

... the rest of your code ...
```

To learn more about the ART client and server, see the docs below.

<div className="cards-container">
  <div className="card-wrapper">
    <Card
      title="ART Client"
      icon="laptop-code"
      href="/fundamentals/art-client"
      horizontal={true}
      arrow={true}
    >
      The client is responsible for interfacing between your code and the ART
      backend.
    </Card>
  </div>
  <div className="card-wrapper">
    <Card
      title="ART Backend"
      icon="server"
      href="/fundamentals/art-backend"
      horizontal={true}
      arrow={true}
    >
      The backend is responsible for generating tokens and training your models.
    </Card>
  </div>
</div>
